# 2. Solvated neutral Pt surface (no bias)

The input file just includes the previous vacuum calculation,
and then adds the solvation parameters:

    fluid LinearPCM
    pcm-variant CANDLE
    fluid-solvent H2O
    fluid-cation Na+ 1.  # 1M cations
    fluid-anion F- 1.    # 1M anions

exactly as we did in the molecule case in the previous session. Here 1M stands for concentration (M = mol/L).


## Run the calculation

Within an interactive session (run `beast-interactive` if not already in one), run:

    srun -n 4 --gpus 4 jdftx_gpu -i in | tee out

The structure of the output should now be very similar to the solvated runs
from the first session: a vacuum calculation to initialize, followed by
solvated calculations at each ionic step.

## Analysis

Let's compare the total energies of the vacuum and neutral cases by `listEnergy ../*/out`:

    -266.896661590294684 ../1_Pt_surf_vac/out
    -266.897887131740561 ../2_Pt_surf_sol/out

Note that the energy difference, the solvation energy of -0.001226 $E_h$ = -0.77 kcal/mol
is much smaller than the corresponding case for the water molecule.
This is because there aren't any significant charge distributions in the neutral surface
that are then stabilized by interaction with the fluid.

Looking at `jdftx.eigStats`, we can see that the absolute Fermi level mu is at -0.195 $E_h$.
In this case, the absolute mu is sensible because the electrolyte in the solvation model
exponentially causes the potential to decay away, making it zero far away within the liquid.
In this situation, the mu corresponds to the potential of zero charge (PZC) of the surface
on an absolute scale.

For the CANDLE solvation model, the standard hydrogen electrode (SHE)
reference potential has been calibrated to be -4.66 eV on an absolute scale.
(See [[	J. Chem. Phys. 142, 064107 (2015)](http://doi.org/10.1063/1.4907731)])
The observed mu (PZC) for Pt(111) then corresponds to -(-0.195 $E_h$ - (-4.66 eV)),
which is (0.195 * 27.2 - 4.66) V = 0.64 V relative to SHE (here 27.2 is the conversion factor from Hartree to eV unit).

Also note the small shift of mu from the previous vacuum case, this implies that the solvent 
introduces a dipole layer that shifts the potential profile relative to the vacuum case.

This is still the canonical ensemble, and the number of electrons stays fixed at the neutral value of 48.

## Visualization

Open Visualize.ipynb using the file browser to examine the solvent bound charge density near the slab.


## Further exercises

Solvate the slabs with H, with more layers and 2x2 supercell from the suggestions at the end of the previous exercise.
How do the adsorption energies and PZC change with slab thickness and coverage?
What is the effect of H adsorption on the PZC relative to the pristine slab.
